@@ -201,7 +201,10 @@ COMMENTS_APP = 'foundry'
 SIMPLE_AUTOCOMPLETE = {
     'auth.user': {'threshold': 20},
     'category.category': {'threshold':20},
-    'jmbo.modelbase': {'threshold':50}
+    'jmbo.modelbase': {
+        'threshold': 50, 
+        'duplicate_format_function': lambda item, model, content_type: item.as_leaf_class().content_type.name
+    }
 }
 
 STATICFILES_FINDERS = ( 
@@ -231,3 +234,5 @@ ADMIN_MODELS_EXCLUDE = (
 JMBO_ANALYTICS = {
     'google_analytics_id': 'xxx',
 }
+
+PHOTOLOGUE_MAXBLOCK = 2 ** 20
